@@ -35,6 +35,17 @@ def get_similarity_scrape(model,all_keywords,main_keyword):
         main_embedding,)
     return np.array(results)
 
+def get_similarity_matrix(model,exisitng_keywords,new_keywords):
+    
+    exisitng_embeddings = model.encode(exisitng_keywords)
+    new_embeddings = model.encode(new_keywords)
+
+    results = cosine_similarity(
+        new_embeddings,
+        exisitng_embeddings,
+    )
+    return np.array(results)
+
 class GadsTestDataset(Dataset):
     def __init__(self,df,tokenizer):
         self.keywords = df['Keywords'].to_numpy()
