@@ -152,10 +152,12 @@ if len(df) != 0:
         df.loc[df["Keywords2"].isin(df_enabled['camp_name'].tolist()),'camp_id'] = df_enabled.loc[df_enabled["camp_name"].isin(df['Keywords2'].tolist()),'camp_id']
 
     # code for altering campaign names
-    paused_campaigns = df_paused['camp_name'].unique().tolist()
-    for i,row in df[df['camp_id'].isna()].iterrows():
-        if row['Keywords2'] in paused_campaigns:
-            df.loc[i,'Keywords2'] = row['Keywords2'] + "_" + str(uuid.uuid4())
+    paused_campaigns_names = df_paused['camp_name'].unique().tolist()
+    df_grouped = df[df['camp_id'].isna()].groupby('Keywords2').groups
+    for seed_keyword, i in df_grouped.items():
+        if seed_keyword in paused_campaigns_names:
+            df.loc[i, 'Keywords2'] = seed_keyword + \
+                "_" + str(uuid.uuid4())
 
 df = df.drop_duplicates('Keywords')
 
