@@ -6,7 +6,7 @@ from transformers import AutoModelForSequenceClassification, AutoTokenizer
 from autoads.keywords import get_keywords_from_api_and_url,get_keywords_from_google
 from autoads.models import get_similarity_api,get_similarity_scrape,get_lfmfuf_predictions
 
-seed_keywords = ['business roth 401k', 'business 401k mutual funds', 'business 401k brokerage window', 'business alt401k', 'business 401k target date funds', 'business 401k plans'] 
+seed_keywords = ["non dilutive funding", "non dilutive financing"] 
 
 #Credentials/Settings for Dataforseo Api 
 email = 'weilbacherindustries@gmail.com' # email in data for seo
