@@ -86,7 +86,7 @@ if len(df_create) != 0:
                 info_dict['keyword_id'].append(keyword_id1)
                 info_dict['keyword_id2'].append(keyword_id2)
                 info_dict['type'].append('created')
-        print(f"{df_create.shape[0]} new campaigns created")
+        print(f"{len(seed_keywords)} new campaigns created")
     except GoogleAdsException as ex:
         _handle_googleads_exception(ex)
 else:
